qixnat - OHSU QIN XNAT helper
=============================

qixnat provides a XNAT facade and helper functions. See the
`documentation <http://qixnat.readthedocs.org/en/latest/>`_
for more information.
